@@ -8,7 +8,10 @@ use Types::Standard qw(HashRef InstanceOf Str);
 
 use WebService::Mattermost::V4::API;
 
-with 'WebService::Mattermost::Role::Returns';
+with qw(
+    WebService::Mattermost::Role::Returns
+    WebService::Mattermost::V4::API::Role::NewRelatedResource
+);
 
 ################################################################################
 
@@ -69,7 +72,7 @@ WebService::Mattermost::V4::API::Object - Base class for results returned from t
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 DESCRIPTION
 
