@@ -27,7 +27,7 @@ sub metadata {
 sub _build_certificate {
     my $self = shift;
 
-    return $self->_new_related_resource('saml', 'SAML::Certificate');
+    return $self->new_related_resource('saml', 'SAML::Certificate');
 }
 
 ################################################################################
@@ -46,7 +46,7 @@ WebService::Mattermost::V4::API::Resource::SAML - Wrapped API methods for the SA
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 DESCRIPTION
 
