@@ -21,13 +21,13 @@ has outgoing => (is => 'ro', isa => InstanceOf[v4 'Webhook::Incoming'], lazy =>
 sub _build_incoming {
     my $self = shift;
 
-    return $self->_new_related_resource('webhooks', 'Webhook::Incoming');
+    return $self->new_related_resource('webhooks', 'Webhook::Incoming');
 }
 
 sub _build_outgoing {
     my $self = shift;
 
-    return $self->_new_related_resource('webhooks', 'Webhook::Outgoing');
+    return $self->new_related_resource('webhooks', 'Webhook::Outgoing');
 }
 
 ################################################################################
@@ -46,7 +46,7 @@ WebService::Mattermost::V4::API::Resource::Webhook - Wrapped API methods for the
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 DESCRIPTION
 
